@@ -53,7 +53,7 @@ IpV4RoutesWidget::IpV4RoutesWidget(QWidget * parent)
 {
     d->ui.setupUi(this);
     d->ui.tableViewAddresses->setModel(&d->model);
-    d->ui.tableViewAddresses->horizontalHeader()->setResizeMode(QHeaderView::Interactive);
+    d->ui.tableViewAddresses->horizontalHeader()->setSectionResizeMode(QHeaderView::Interactive);
 
     IpV4Delegate *ipDelegate = new IpV4Delegate(this);
     IntDelegate *metricDelegate = new IntDelegate(this);
@@ -108,7 +108,7 @@ bool IpV4RoutesWidget::ignoreautoroutes() const
 void IpV4RoutesWidget::setRoutes(const QList<NetworkManager::IpRoute> &list)
 {
     d->model.removeRows(0, d->model.rowCount());
-    Q_FOREACH (const NetworkManager::IpRoute &route, list) {
+    for (const NetworkManager::IpRoute &route : list) {
         QList<QStandardItem *> item;
 
         // qCDebug(PLASMA_NM) << route.ip();
